==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/lib_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_comment_preview'] = 					"comment preview";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_contents'] = 						"contents";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";


// SUB
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";


// BODY
$lang['txt_library'] = 							"wiki";//breadcrumb
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_wiki_default'] = 					"LibraryFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_published_to'] = 					"Published to";
$lang['href_wiki_first_page'] = 				"start your library";
$lang['txt_check_spelling'] =					"Check Spelling";

?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/lib_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['section_add_comment'] = 					"add comment";
$lang['hdr_comment_preview'] = 					"comment preview";
$lang['hdr_tag'] = 								"tags";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_contents'] = 						"contents";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";
$lang['href_wiki_first_page'] = 				"start your library";


// SUB
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_save'] = 							"save";
$lang['sub_update_tag'] = 						"update my tags";


// BODY
$lang['txt_library'] = 							"wiki";//breadcrumb
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_wiki_default'] = 					"LibraryFirstPage"; //must be WIKI formatted LikeThisExample
$lang['txt_published_to'] = 					"Published to";
$lang['txt_check_spelling'] =					"Check Spelling";
$lang['txt_tag_intro'] = 						"This wiki page has been tagged with";
$lang['txt_tag_network'] = 						"My network have tagged this wiki page with";
$lang['txt_tag_group'] = 						"This group has tagged this wiki page with";
$lang['txt_non_member'] = 						"NON MEMBER";
$lang['txt_joined'] = 							"Joined";
$lang['txt_hometown'] = 						"Hometown";


?>
